# -*- coding: utf-8 -*-
# Copyright (c) Virtual Reality and Clinical Gait Analysis Laboratory

__title__ = 'vrcgal_py'
__description__ = 'Virtual Reality and Clinical Gait Analysis Laboratory Python Tools' # noqa E501
__url__ = 'https://github.com/vrcgal/vrcgal_py'
__version__ = '1.0.0'
__build__ = 0x000003
__author__ = 'Ben Long'
__author_email__ = '14benj@gmail.com'
__license__ = 'MIT'
__copyright__ = 'Copyright (c) Virtual Reality and Clinical Gait Analysis Laboratory, High Point University' # noqa E501