# -*- coding: utf-8 -*-
# Copyright (c) Virtual Reality and Clinical Gait Analysis Laboratory

from distutils.core import setup


setup(
    name='vrcgal_py',
    version='1.0.0',
    packages=['vrcgal_py'],
    license='MIT',
    url='https://github.com/vrcgal/vrcgal_py',
    author='Ben Long',
    author_email="14benj@gmail.com",
    long_description=open('README').read()
)
